function [vhat,ci95,vhatroot,ci95root,output] = jpe_EstimateV(Zcont,Yjump,Zjump,deltan,Nsimul,k)

%% Notes
% Input
%
% Zcont:  kn x 4, diffusive returns of Z index by q in {tau-,tau+,eta-,eta+}
% Yjump: N x 2, jumps in Y
% Zjump: 1 x 2, jumps in Z
% deltan: sampling interval
% Nsimul: number of simulations for generating CV
% k: mixed scale


% Output
% 
% vhat: \hat{v}, the variance of beta innovations
% vhatroot: sqrt{\hat{v}}, the std deviation of beta innovations
% ci95: the confidence intervals for v
% ci95root: the confidence interval for sqrt(v)
% output: collecting all relevant output, can be printed via jpe_print(output)


%% Code begins here

% Step 1. 
% Estimate spot beta [beta: N x 2] and test stat
[N,junk] = size(Yjump);
[kn,junk] = size(Zcont);
beta = Yjump ./ repmat(Zjump,N,1); % spot betas [N x 2]
vhat = mean((beta(:,1) - beta(:,2)).^2); % \hat{v}, the estimate of beta variation
vhatroot = sqrt(vhat);

% Step 2. Estimate spot vol for Z at the latter jump (tau)
spotvol_tauminus = sum(Zcont(:,3).^2) / kn / deltan;
spotvol_tauplus  = sum(Zcont(:,4).^2) / kn / deltan;

% Step 3. Estimate Sigma_S
SigmaS = mean((beta(:,1) - beta(:,2)).^4) - vhat^2;

% Step 4. Simulation
vsimul = zeros(Nsimul,1); % Simulated vtilde
theta = N * deltan;
parfor mc = 1:Nsimul
    S_tilde = randn(1) * sqrt(SigmaS);
    kappa_tau = rand(1);
    vsimul(mc) = S_tilde - 2 * sqrt(theta) * vhat * (...
    sqrt(kappa_tau) / Zjump(2) * randn(1) * sqrt(spotvol_tauminus) + ...
    sqrt(k-kappa_tau) / Zjump(2) * randn(1) * sqrt(spotvol_tauplus));
end
q90 = prctile(abs(vsimul),95);
q95 = prctile(abs(vsimul),97.5);
q99 = prctile(abs(vsimul),99.5);
ci90 = [vhat - q90 / sqrt(N), vhat + q90 / sqrt(N)];
ci95 = [vhat - q95 / sqrt(N), vhat + q95 / sqrt(N)];
ci99 = [vhat - q99 / sqrt(N), vhat + q99 / sqrt(N)];

q95root = prctile(abs(vsimul/2/sqrt(vhat)),97.5);
ci95root = [vhatroot - q95root / sqrt(N), vhatroot + q95root / sqrt(N)];

output.vhat = vhat;
output.Nsimul = Nsimul;
output.deltan = deltan;
output.k = k;
output.beta = beta;
output.vsimul = vsimul;
output.SigmaS = SigmaS;
output.ci90 = ci90;
output.ci95 = ci95;
output.ci99 = ci99;
output.ci95root = ci95root;
output.type = 'EstimateV';


